@@ -5,4 +5,7 @@ titanic_f = pkg_resources.resource_filename(__name__, 'titanic/titanic.csv')
 titanic_df = pd.read_csv(titanic_f)
 
 ibd_f = pkg_resources.resource_filename(__name__, 'ibd/IBD.csv')
-ibd_df = pd.read_csv(titanic_f)
\ No newline at end of file
+ibd_df = pd.read_csv(ibd_f)
+
+hr_f = pkg_resources.resource_filename(__name__, 'HR/HR.csv')
+hr_df = pd.read_csv(hr_f)
\ No newline at end of file
